from setuptools import setup, find_packages
  
setup( 
    name='homework_1_dimitri', 
    version='0.0.1', 
    description='First Homework', 
    author='Dimitri Dondoladze', 
    author_email='dimitri.dondoladze.1@iliauni.edu.ge', 
    packages=find_packages(),
    install_requires=[ ], 
) 
